# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`icingadb`](#icingadb): Puppet class to manage IcingaDB.
* [`icingadb::globals`](#icingadb--globals): This class loads the default parameters by doing a hiera lookup.
* [`icingadb::redis`](#icingadb--redis): Manage the IcingaDB Redis server.
* [`icingadb::redis::globals`](#icingadb--redis--globals): This class loads the default parameters by doing a hiera lookup.

#### Private Classes

* `icingadb::config`: A short summary of the purpose of this class
Configures IcingaDB
* `icingadb::install`: Installs IcingaDB
* `icingadb::install::db`: Imports IcingaDB database schema
* `icingadb::redis::config`: Configures IcingaDB Redis server
* `icingadb::redis::install`: Installs IcingaDB Redis server
* `icingadb::redis::service`: Manage IcingaDB Redis server service
* `icingadb::service`: Manage IcingaDB service

### Data types

* [`IcingaDB::DBOptions`](#IcingaDB--DBOptions): Data type for options to connect the IcingaDB database.
* [`IcingaDB::LoggingOptions`](#IcingaDB--LoggingOptions): Logging options data type for the IcingaDB process.
* [`IcingaDB::RetentionOptions`](#IcingaDB--RetentionOptions): Data type for retention options of the connection to
the IcingaDB database.

## Classes

### <a name="icingadb"></a>`icingadb`

Puppet class to manage IcingaDB.

#### Examples

##### 

```puppet
class { 'icingadb':
  manage_repos  => true,
  db_type       => 'pgsql',
  db_password   => 'supersecret',
  import_schema => true,
}
```

#### Parameters

The following parameters are available in the `icingadb` class:

* [`ensure`](#-icingadb--ensure)
* [`enable`](#-icingadb--enable)
* [`manage_repos`](#-icingadb--manage_repos)
* [`manage_packages`](#-icingadb--manage_packages)
* [`redis_host`](#-icingadb--redis_host)
* [`redis_port`](#-icingadb--redis_port)
* [`redis_password`](#-icingadb--redis_password)
* [`redis_use_tls`](#-icingadb--redis_use_tls)
* [`redis_tls_insecure`](#-icingadb--redis_tls_insecure)
* [`redis_tls_cert`](#-icingadb--redis_tls_cert)
* [`redis_tls_cert_file`](#-icingadb--redis_tls_cert_file)
* [`redis_tls_key`](#-icingadb--redis_tls_key)
* [`redis_tls_key_file`](#-icingadb--redis_tls_key_file)
* [`redis_tls_cacert`](#-icingadb--redis_tls_cacert)
* [`redis_tls_cacert_file`](#-icingadb--redis_tls_cacert_file)
* [`db_type`](#-icingadb--db_type)
* [`db_host`](#-icingadb--db_host)
* [`db_port`](#-icingadb--db_port)
* [`db_name`](#-icingadb--db_name)
* [`db_username`](#-icingadb--db_username)
* [`db_password`](#-icingadb--db_password)
* [`import_schema`](#-icingadb--import_schema)
* [`db_use_tls`](#-icingadb--db_use_tls)
* [`db_tls_insecure`](#-icingadb--db_tls_insecure)
* [`db_tls_cert`](#-icingadb--db_tls_cert)
* [`db_tls_cert_file`](#-icingadb--db_tls_cert_file)
* [`db_tls_key`](#-icingadb--db_tls_key)
* [`db_tls_key_file`](#-icingadb--db_tls_key_file)
* [`db_tls_cacert`](#-icingadb--db_tls_cacert)
* [`db_tls_cacert_file`](#-icingadb--db_tls_cacert_file)
* [`db_options`](#-icingadb--db_options)
* [`logging_level`](#-icingadb--logging_level)
* [`logging_output`](#-icingadb--logging_output)
* [`logging_interval`](#-icingadb--logging_interval)
* [`logging_options`](#-icingadb--logging_options)
* [`retention_history_data`](#-icingadb--retention_history_data)
* [`retention_sla_data`](#-icingadb--retention_sla_data)
* [`retention_options`](#-icingadb--retention_options)

##### <a name="-icingadb--ensure"></a>`ensure`

Data type: `Enum['running', 'stopped']`

Choose wether the service is `running` or `stopped`.

Default value: `'running'`

##### <a name="-icingadb--enable"></a>`enable`

Data type: `Boolean`

Choose wether the service has to start at boot.

Default value: `true`

##### <a name="-icingadb--manage_repos"></a>`manage_repos`

Data type: `Boolean`

Whether to involve the Icinga repositories.

Default value: `false`

##### <a name="-icingadb--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Whether to manage the IcingaDB packages.

Default value: `true`

##### <a name="-icingadb--redis_host"></a>`redis_host`

Data type: `Stdlib::Host`

Redis server to connect.

Default value: `'localhost'`

##### <a name="-icingadb--redis_port"></a>`redis_port`

Data type: `Stdlib::Port`

Port on the Redis host to connect.

Default value: `6380`

##### <a name="-icingadb--redis_password"></a>`redis_password`

Data type: `Optional[Icinga::Secret]`

Passwort to login into redis.

Default value: `undef`

##### <a name="-icingadb--redis_use_tls"></a>`redis_use_tls`

Data type: `Optional[Boolean]`

Wether or not to enable tls encryption to connect the database.

Default value: `undef`

##### <a name="-icingadb--redis_tls_insecure"></a>`redis_tls_insecure`

Data type: `Optional[Boolean]`

Disable the server certificate validation. Only valid if `redis_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis_tls_cert"></a>`redis_tls_cert`

Data type: `Optional[String[1]]`

Client certificate in PEM format. Only valid if `redis_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis_tls_cert_file"></a>`redis_tls_cert_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the client certificate. Only valid if `redis_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis_tls_key"></a>`redis_tls_key`

Data type: `Optional[Icinga::Secret]`

Client private key in PEM format. Only valid if `redis_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis_tls_key_file"></a>`redis_tls_key_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the client private key. Only valid if `redis_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis_tls_cacert"></a>`redis_tls_cacert`

Data type: `Optional[String[1]]`

CA root certificate in PEM format. Only valid if `redis_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis_tls_cacert_file"></a>`redis_tls_cacert_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the CA root certificate. Only valid if `redis_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--db_type"></a>`db_type`

Data type: `Enum['mysql','pgsql']`

Choose wether MySQL or PostgreSQL as backend for historical data.

Default value: `'mysql'`

##### <a name="-icingadb--db_host"></a>`db_host`

Data type: `Stdlib::Host`

Database server.

Default value: `'localhost'`

##### <a name="-icingadb--db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port]`

Port to connect the database.

Default value: `undef`

##### <a name="-icingadb--db_name"></a>`db_name`

Data type: `String[1]`

The IcingaDB database.

Default value: `'icingadb'`

##### <a name="-icingadb--db_username"></a>`db_username`

Data type: `String[1]`

User that is used to connect the database.

Default value: `'icingadb'`

##### <a name="-icingadb--db_password"></a>`db_password`

Data type: `Icinga::Secret`

Passwort to login into database.

##### <a name="-icingadb--import_schema"></a>`import_schema`

Data type: `Variant[Boolean, Enum['mariadb', 'mysql']]`

Whether or not to import the databse schema or not. Options `mariadb` and `mysql`,
both means true. With mariadb its cli options are used for the import,
whereas with mysql its different options.

Default value: `false`

##### <a name="-icingadb--db_use_tls"></a>`db_use_tls`

Data type: `Optional[Boolean]`

Wether or not to enable tls encryption to connect the database.

Default value: `undef`

##### <a name="-icingadb--db_tls_insecure"></a>`db_tls_insecure`

Data type: `Optional[Boolean]`

Disable the server certificate validation. Only valid if `db_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--db_tls_cert"></a>`db_tls_cert`

Data type: `Optional[String[1]]`

Client certificate in PEM format. Only valid if `db_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--db_tls_cert_file"></a>`db_tls_cert_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the client certificate. Only valid if `db_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--db_tls_key"></a>`db_tls_key`

Data type: `Optional[Icinga::Secret]`

Client private key in PEM format. Only valid if `db_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--db_tls_key_file"></a>`db_tls_key_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the client private key. Only valid if `db_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--db_tls_cacert"></a>`db_tls_cacert`

Data type: `Optional[String[1]]`

CA root certificate in PEM format. Only valid if `db_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--db_tls_cacert_file"></a>`db_tls_cacert_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the CA root certificate. Only valid if `db_use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--db_options"></a>`db_options`

Data type: `IcingaDB::DBOptions`

List of low-level database options that can be set to influence some
Icinga DB internal default behaviours.

Default value: `{}`

##### <a name="-icingadb--logging_level"></a>`logging_level`

Data type: `Enum['fatal','error','warn','info','debug']`

Specifies the default logging level. Can be set to fatal, error, warn, info or debug.

Default value: `'info'`

##### <a name="-icingadb--logging_output"></a>`logging_output`

Data type: `Optional[Enum['console','systemd-journald']]`

Configures the logging output. Can be set to console (stderr) or systemd-journald.

Default value: `undef`

##### <a name="-icingadb--logging_interval"></a>`logging_interval`

Data type: `Pattern[/^\d+\.?\d*[d|h|m|s]?$/]`

Interval for periodic logging defined as duration string.

Default value: `'20s'`

##### <a name="-icingadb--logging_options"></a>`logging_options`

Data type: `IcingaDB::LoggingOptions`

Map of component-logging level pairs to define a different log level than
the default value for each component.

Default value: `{}`

##### <a name="-icingadb--retention_history_data"></a>`retention_history_data`

Data type: `Optional[Integer[1]]`

Number of days to retain full historical data.

Default value: `undef`

##### <a name="-icingadb--retention_sla_data"></a>`retention_sla_data`

Data type: `Optional[Integer[1]]`

Number of days to retain historical data for SLA reporting.

Default value: `undef`

##### <a name="-icingadb--retention_options"></a>`retention_options`

Data type: `IcingaDB::RetentionOptions`

Map of history category to number of days to retain its data in order to
enable retention only for specific categories or to override the number
that has been configured in `retention_history_data`.

Default value: `{}`

### <a name="icingadb--globals"></a>`icingadb::globals`

This class loads the default parameters by doing a hiera lookup.

#### Parameters

The following parameters are available in the `icingadb::globals` class:

* [`package_name`](#-icingadb--globals--package_name)
* [`service_name`](#-icingadb--globals--service_name)
* [`user`](#-icingadb--globals--user)
* [`group`](#-icingadb--globals--group)
* [`conf_dir`](#-icingadb--globals--conf_dir)
* [`mysql_db_schema`](#-icingadb--globals--mysql_db_schema)
* [`pgsql_db_schema`](#-icingadb--globals--pgsql_db_schema)

##### <a name="-icingadb--globals--package_name"></a>`package_name`

Data type: `String[1]`



##### <a name="-icingadb--globals--service_name"></a>`service_name`

Data type: `String[1]`



##### <a name="-icingadb--globals--user"></a>`user`

Data type: `String[1]`



##### <a name="-icingadb--globals--group"></a>`group`

Data type: `String[1]`



##### <a name="-icingadb--globals--conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`



##### <a name="-icingadb--globals--mysql_db_schema"></a>`mysql_db_schema`

Data type: `Stdlib::Absolutepath`



##### <a name="-icingadb--globals--pgsql_db_schema"></a>`pgsql_db_schema`

Data type: `Stdlib::Absolutepath`



### <a name="icingadb--redis"></a>`icingadb::redis`

Manage the IcingaDB Redis server.

#### Examples

##### Enable required repositories, bind Redis on Port `6380` (default) on localhost and increase keepalive and number of databases.

```puppet
class { 'icingadb::redis':
  manage_repos => true,
  bind         => '127.0.0.1',
  port         => 6380,
  config       => {
    tcp_keepalive => 400,
    databases     => 8,
  }
}
```

##### Bind Redis to port 6380 an for encrypted connections to 6381 (default) on localhost and the main interface. Also force an authentication by password.

```puppet
class { 'icingadb::redis':
  bind             => ['127.0.0.1', $::ipaddress],
  requirepass      => Sensitive('supersecret'),
  use_tls          => true,
  tls_port         => 6381,
  tls_cert_file    => '/etc/icingadb-redis/server.crt',
  tls_key_file     => '/etc/icingadb-redis/server.key',
  tls_cacert_file  => '/etc/icingadb-redis/ca.crt',
}
```

##### Bind Redis for encrypted only connections to 6380 on localhost and the main interface. Also force a valid client certificate for authentication.

```puppet
class { 'icingadb::redis':
  bind             => ['127.0.0.1', $::ipaddress],
  use_tls          => true,
  tls_port         => 6380,
  tls_cert_file    => '/etc/icingadb-redis/server.crt',
  tls_key_file     => '/etc/icingadb-redis/server.key',
  tls_cacert_file  => '/etc/icingadb-redis/ca.crt',
  tls_auth_clients => 'yes',
}
```

#### Parameters

The following parameters are available in the `icingadb::redis` class:

* [`ensure`](#-icingadb--redis--ensure)
* [`enable`](#-icingadb--redis--enable)
* [`bind`](#-icingadb--redis--bind)
* [`port`](#-icingadb--redis--port)
* [`manage_repos`](#-icingadb--redis--manage_repos)
* [`manage_packages`](#-icingadb--redis--manage_packages)
* [`requirepass`](#-icingadb--redis--requirepass)
* [`use_tls`](#-icingadb--redis--use_tls)
* [`tls_port`](#-icingadb--redis--tls_port)
* [`tls_cert`](#-icingadb--redis--tls_cert)
* [`tls_key`](#-icingadb--redis--tls_key)
* [`tls_cacert`](#-icingadb--redis--tls_cacert)
* [`tls_cert_file`](#-icingadb--redis--tls_cert_file)
* [`tls_key_file`](#-icingadb--redis--tls_key_file)
* [`tls_cacert_file`](#-icingadb--redis--tls_cacert_file)
* [`tls_auth_clients`](#-icingadb--redis--tls_auth_clients)
* [`config`](#-icingadb--redis--config)

##### <a name="-icingadb--redis--ensure"></a>`ensure`

Data type: `Enum['running','stopped']`

Choose wether the service is `running` or `stopped`.

Default value: `'running'`

##### <a name="-icingadb--redis--enable"></a>`enable`

Data type: `Boolean`

Choose wether the service has to start at boot.

Default value: `true`

##### <a name="-icingadb--redis--bind"></a>`bind`

Data type: `Variant[Stdlib::Host,Array[Stdlib::Host]]`

Configure which IP address(es) to listen on. To bind on
all interfaces, use an empty array.

Default value: `['127.0.0.1', '::1']`

##### <a name="-icingadb--redis--port"></a>`port`

Data type: `Stdlib::Port`

Configure which port to listen on.

Default value: `6380`

##### <a name="-icingadb--redis--manage_repos"></a>`manage_repos`

Data type: `Boolean`

Whether to involve the Icinga repositories.

Default value: `false`

##### <a name="-icingadb--redis--manage_packages"></a>`manage_packages`

Data type: `Boolean`

Whether or not to manage the IcingaDB packages.

Default value: `true`

##### <a name="-icingadb--redis--requirepass"></a>`requirepass`

Data type: `Optional[Icinga::Secret]`

Require clients to issue AUTH <PASSWORD> before processing
any other commands.

Default value: `undef`

##### <a name="-icingadb--redis--use_tls"></a>`use_tls`

Data type: `Optional[Boolean]`

Wether or not to enable tls encryption.

Default value: `undef`

##### <a name="-icingadb--redis--tls_port"></a>`tls_port`

Data type: `Stdlib::Port`

Configure which port to listen on for tls encrypted connection. Only valid if `use_tls` is turned on.

Default value: `6381`

##### <a name="-icingadb--redis--tls_cert"></a>`tls_cert`

Data type: `Optional[String[1]]`

Certificate in PEM format. Only valid if `use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis--tls_key"></a>`tls_key`

Data type: `Optional[Icinga::Secret]`

Private key in PEM format. Only valid if `use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis--tls_cacert"></a>`tls_cacert`

Data type: `Optional[String[1]]`

The CA root certificate in PEM format. Only valid if `use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis--tls_cert_file"></a>`tls_cert_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the certificate file. Only valid if `use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis--tls_key_file"></a>`tls_key_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the private key file. Only valid if `use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis--tls_cacert_file"></a>`tls_cacert_file`

Data type: `Optional[Stdlib::Absolutepath]`

Location of the CA root certificate. Only valid if `use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis--tls_auth_clients"></a>`tls_auth_clients`

Data type: `Optional[Enum['yes', 'no', 'optional']]`

Set to `yes` to force authentication with a valid client certificate.
Other Options are `no` and `optional`. Only valid if `use_tls` is turned on.

Default value: `undef`

##### <a name="-icingadb--redis--config"></a>`config`

Data type: `Hash[String[1], Any]`

Other parameters that can be set, see redis::instance.

Default value: `{}`

### <a name="icingadb--redis--globals"></a>`icingadb::redis::globals`

This class loads the default parameters by doing a hiera lookup.

#### Parameters

The following parameters are available in the `icingadb::redis::globals` class:

* [`package_name`](#-icingadb--redis--globals--package_name)
* [`service_name`](#-icingadb--redis--globals--service_name)
* [`user`](#-icingadb--redis--globals--user)
* [`group`](#-icingadb--redis--globals--group)
* [`redis_bin`](#-icingadb--redis--globals--redis_bin)
* [`conf_dir`](#-icingadb--redis--globals--conf_dir)
* [`work_dir`](#-icingadb--redis--globals--work_dir)
* [`run_dir`](#-icingadb--redis--globals--run_dir)
* [`log_dir`](#-icingadb--redis--globals--log_dir)

##### <a name="-icingadb--redis--globals--package_name"></a>`package_name`

Data type: `String[1]`



##### <a name="-icingadb--redis--globals--service_name"></a>`service_name`

Data type: `String[1]`



##### <a name="-icingadb--redis--globals--user"></a>`user`

Data type: `String[1]`



##### <a name="-icingadb--redis--globals--group"></a>`group`

Data type: `String[1]`



##### <a name="-icingadb--redis--globals--redis_bin"></a>`redis_bin`

Data type: `Stdlib::Absolutepath`



##### <a name="-icingadb--redis--globals--conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`



##### <a name="-icingadb--redis--globals--work_dir"></a>`work_dir`

Data type: `Stdlib::Absolutepath`



##### <a name="-icingadb--redis--globals--run_dir"></a>`run_dir`

Data type: `Stdlib::Absolutepath`



##### <a name="-icingadb--redis--globals--log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`



## Data types

### <a name="IcingaDB--DBOptions"></a>`IcingaDB::DBOptions`

Data type for options to connect the IcingaDB database.

Alias of

```puppet
Hash[Enum[
    'max_connections',
    'max_connections_per_table',
    'max_placeholders_per_statement',
    'max_rows_per_transaction',
    'wsrep_sync_wait'
  ], Integer[1]]
```

### <a name="IcingaDB--LoggingOptions"></a>`IcingaDB::LoggingOptions`

Logging options data type for the IcingaDB process.

Alias of

```puppet
Hash[Enum[
    'config-sync','database','dump-signals',
    'heartbeat','high-availability',
    'history-sync','overdue-sync','redis',
    'retention','runtime-updates','telemetry'
  ], Enum['fatal','error','warn','info','debug']]
```

### <a name="IcingaDB--RetentionOptions"></a>`IcingaDB::RetentionOptions`

Data type for retention options of the connection to
the IcingaDB database.

Alias of

```puppet
Hash[Enum[
    'acknowledgement','comment','downtime',
    'flapping','notification','state'
  ], Integer[1]]
```

